summaryrefslogtreecommitdiff
path: root/ace/SPIPE_Stream.cpp
diff options
context:
space:
mode:
authorirfan <irfan@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1998-09-17 20:22:38 +0000
committerirfan <irfan@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1998-09-17 20:22:38 +0000
commit864bdc2174ef996fa55ed5466ee6d7862873feda (patch)
tree874e6c77f07c532cbd4ba6da53db76fc9438ba8a /ace/SPIPE_Stream.cpp
parentae77e4c4d6c693f9c4fce9811a2b9a241477ea63 (diff)
downloadATCD-864bdc2174ef996fa55ed5466ee6d7862873feda.tar.gz
ChangeLog
Diffstat (limited to 'ace/SPIPE_Stream.cpp')
-rw-r--r--ace/SPIPE_Stream.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/ace/SPIPE_Stream.cpp b/ace/SPIPE_Stream.cpp
index 1430fa8dfdb..29a5433dd3d 100644
--- a/ace/SPIPE_Stream.cpp
+++ b/ace/SPIPE_Stream.cpp
@@ -36,11 +36,11 @@ ACE_SPIPE_Stream::send (size_t n, ...) const
// ACE_TRACE ("ACE_SPIPE_Stream::send");
va_list argp;
size_t total_tuples = n / 2;
- ACE_IO_Vector_Base *iovp;
+ iovec *iovp;
#if defined (ACE_HAS_ALLOCA)
- iovp = (ACE_IO_Vector_Base *) alloca (total_tuples * sizeof (ACE_IO_Vector_Base));
+ iovp = (iovec *) alloca (total_tuples * sizeof (iovec));
#else
- ACE_NEW_RETURN (iovp, ACE_IO_Vector_Base[total_tuples], -1);
+ ACE_NEW_RETURN (iovp, iovec[total_tuples], -1);
#endif /* !defined (ACE_HAS_ALLOCA) */
va_start (argp, n);
@@ -60,7 +60,7 @@ ACE_SPIPE_Stream::send (size_t n, ...) const
}
// This is basically an interface to ACE_OS::readv, that doesn't use
// the struct ACE_IO_Vector_Base explicitly. The ... can be passed as an arbitrary
// number of (char *ptr, int len) tuples. However, the count N is the
// *total* number of trailing arguments, *not* a couple of the number
// of tuple pairs!
@@ -71,11 +71,11 @@ ACE_SPIPE_Stream::recv (size_t n, ...) const
ACE_TRACE ("ACE_SPIPE_Stream::recv");
va_list argp;
size_t total_tuples = n / 2;
- ACE_IO_Vector_Base *iovp;
+ iovec *iovp;
#if defined (ACE_HAS_ALLOCA)
- iovp = (ACE_IO_Vector_Base *) alloca (total_tuples * sizeof (ACE_IO_Vector_Base));
+ iovp = (iovec *) alloca (total_tuples * sizeof (iovec));
#else
- ACE_NEW_RETURN (iovp, ACE_IO_Vector_Base[total_tuples], -1);
+ ACE_NEW_RETURN (iovp, iovec[total_tuples], -1);
#endif /* !defined (ACE_HAS_ALLOCA) */
va_start (argp, n);
@@ -60,7 +60,7 @@ ACE_SPIPE_Stream::send (size_t n, ...) const
}
// This is basically an interface to ACE_OS::readv, that doesn't use
-// the struct ACE_IO_Vector_Base explicitly. The ... can be passed as an arbitrary
+// the struct iovec explicitly. The ... can be passed as an arbitrary
// number of (char *ptr, int len) tuples. However, the count N is the
// *total* number of trailing arguments, *not* a couple of the number